@@ -1,4 +1,4 @@
-################################################################################
+############################################################################## #
 # Copyright (C) 2019 by 52 North                                               #
 # Initiative for Geospatial Open Source Software GmbH                          #
 #                                                                              #
@@ -25,7 +25,7 @@
 # Created: 2010-06-18                                                          #
 # Project: sos4R - https://github.com/52North/sos4R                            #
 #                                                                              #
-################################################################################
+############################################################################## #
 
 #
 # construction methods
@@ -50,16 +50,4 @@ SweTextBlock <- function(tokenSeparator, blockSeparator, decimalSeparator,
   new("SweTextBlock", tokenSeparator = tokenSeparator,
       blockSeparator = blockSeparator,
       decimalSeparator = decimalSeparator, id = id)
-}
-
-
-# SWE 2.0
-
-SweTextEncoding <- function(tokenSeparator, blockSeparator, decimalSeparator = as.character(NA),
-                            id = as.character(NA)) {
-  new("SweTextEncoding", tokenSeparator = tokenSeparator,
-      blockSeparator = blockSeparator,
-      decimalSeparator = decimalSeparator, id = id)
-}
-
-
+}
\ No newline at end of file
