@@ -1,10 +1,34 @@
-# Copyright (C) 2019 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
-# This program is free software; you can redistribute and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation. This program is distributed WITHOUT ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program (see gpl-2.0.txt). If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or visit the Free Software Foundation web page, http://www.fsf.org.
-# Author: Daniel Nuest (daniel.nuest@uni-muenster.de)
-# Project: sos4R - visit the project web page: https://github.com/52North/sos4R
-library("sos4R");
-library("ggplot2");
-library("latticeExtra");
+############################################################################## #
+# Copyright (C) 2019 by 52 North                                               #
+# Initiative for Geospatial Open Source Software GmbH                          #
+#                                                                              #
+# Contact: Andreas Wytzisk                                                     #
+# 52 North Initiative for Geospatial Open Source Software GmbH                 #
+# Martin-Luther-King-Weg 24                                                    #
+# 48155 Muenster, Germany                                                      #
+# info@52north.org                                                             #
+#                                                                              #
+# This program is free software; you can redistribute and/or modify it under   #
+# the terms of the GNU General Public License version 2 as published by the    #
+# Free Software Foundation.                                                    #
+#                                                                              #
+# This program is distributed WITHOUT ANY WARRANTY; even without the implied   #
+# WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU #
+# General Public License for more details.                                     #
+#                                                                              #
+# You should have received a copy of the GNU General Public License along with #
+# this program (see gpl-2.0.txt). If not, write to the Free Software           #
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or #
+# visit the Free Software Foundation web page, http://www.fsf.org.             #
+#                                                                              #
+# Author: Daniel Nuest (daniel.nuest@uni-muenster.de)                          #
+# Project: sos4R - https://github.com/52North/sos4R                            #
+#                                                                              #
+############################################################################## #
+
+library("sos4R")
+library("ggplot2")
+library("latticeExtra")
 library("quantreg")
 
 ##############################################################################
@@ -39,7 +63,6 @@ tPeriod <- sosCreateEventTimeList(
 				sos = pegelsos,
 				begin = Sys.time() - (3600 * 24 * tPeriod.days),
 				end = Sys.time()))
-#tPeriod # str(tPeriod)
 #encodeXML(tPeriod[[1]], pegelsos)
 
 # three procedures, but only getting 1 element with one procedure...
